# -*- coding: utf-8 -*-
from setuphelpers import *
from setupdevhelpers import *
import requests
import waptlicences

def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name

    architecture = control.architecture
    url = "https://openvpn.net/client/client-connect-vpn-for-windows/"

    for link in bs_find_all(url, 'a', "target", "_self", proxies=proxies):
        href = link['href']
        if href.endswith('.msi'):
            if architecture == 'x86' and 'windows-x86' in href:
                msi_link = href
                break
            elif architecture == 'x64' and 'windows' in href:
                msi_link = href
                break

    download_url = requests.head(msi_link, proxies=proxies, allow_redirects=True).url
    latest_bin = download_url.rsplit('/', 1)[-1]
    latest_bin_extension = latest_bin.rsplit('.', 1)[-1]

    # Downloading latest binaries
    print(f"Download URL is: {download_url}")
    if not isfile(latest_bin):
        print(f"Downloading: {latest_bin}")
        wget(download_url, latest_bin, proxies=proxies)
    else:
        print(f"Binary is present: {latest_bin}")

    # Obtenir la version à partir du binaire
    version = get_version_from_binary(latest_bin)

    expected_issuer = "OpenVPN Inc."
    sign_name = waptlicences.check_msi_signature(latest_bin)[0]
    if sign_name != expected_issuer:
        error(f'Bad issuer {sign_name} != {expected_issuer} ')

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print(f"Software version updated (from: {control.get_software_version()} to: {Version(version)})")
        package_updated = True
    else:
        print(f"Software version up-to-date ({Version(version)})")

    for f in glob.glob(f'*.{latest_bin_extension}'):
        if f != latest_bin:
            remove_file(f)

    control.set_software_version(version)
    control.save_control_to_wapt()

    return package_updated